<?php

namespace Drupal\simple_admin_theme_by_route\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Theme\ThemeInitializationInterface;
use Drupal\Core\Theme\ThemeManagerInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\Event\RequestEvent;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\Routing\RouterInterface;

/**
 * Event subscriber to change theme in content types.
 */
class AdminThemeSubscriber implements EventSubscriberInterface {

  /**
   * Event subscriber constructor.
   *
   * @param \Drupal\Core\Theme\ThemeInitializationInterface $themeInitialization
   *   Interface which contain theme initialization logic.
   * @param \Symfony\Component\Routing\RouterInterface $router
   *   The router manager.
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Theme\ThemeManagerInterface $themeManager
   *   The theme manager.
   */
  public function __construct(
    protected readonly ThemeInitializationInterface $themeInitialization,
    protected readonly RouterInterface $router,
    protected readonly ConfigFactoryInterface $configFactory,
    protected readonly ThemeManagerInterface $themeManager,
  ) {}

  /**
   * Event handler.
   *
   * @param \Symfony\Component\HttpKernel\Event\RequestEvent $event
   *   Event data.
   */
  public function onKernelRequest(RequestEvent $event) {
    $request = $event->getRequest();

    $admin_theme_routes = $this->configFactory->get('simple_admin_theme_by_route.settings')->get('admin_theme_routes') ?? [];

    $parameters = [];
    try {
      $route_object = $this->router->matchRequest($request, $parameters);
    }
    catch (\Exception $e) {
      return;
    }
    if (!empty($route_object['_route']) && in_array($route_object['_route'], $admin_theme_routes, TRUE)) {
      $system_theme = $this->configFactory->get('system.theme');
      $admin_theme_name = $system_theme->get('admin');

      $this->themeManager->setActiveTheme($this->themeInitialization->initTheme($admin_theme_name));
    }
  }

  /**
   * {@inheritDoc}
   */
  public static function getSubscribedEvents() {
    return [
      KernelEvents::REQUEST => ['onKernelRequest', 35],
    ];
  }

}
