<?php

declare(strict_types=1);

namespace Drupal\simple_admin_theme_by_route\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Simple Admin Theme by Route settings.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'simple_admin_theme_by_route_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['simple_admin_theme_by_route.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('simple_admin_theme_by_route.settings');

    $form['admin_theme_routes'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Admin theme routes'),
      '#description' => $this->t('Enter one route per line where the admin theme should be used. Example: <code>entity.payment_order.canonical</code>'),
      '#default_value' => implode("\n", $config->get('admin_theme_routes') ?? []),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    $routes = array_filter(array_map('trim', explode("\n", $form_state->getValue('admin_theme_routes'))));

    foreach ($routes as $route) {
      if (!preg_match('/^[a-z0-9_.-]+$/', $route)) {
        $form_state->setErrorByName('admin_theme_routes', $this->t('Invalid route name: %route.', ['%route' => $route]));
        break;
      }
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $routes = array_filter(array_map('trim', explode("\n", $form_state->getValue('admin_theme_routes'))));

    $this->config('simple_admin_theme_by_route.settings')
      ->set('admin_theme_routes', $routes)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
